#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const repl_1 = require("repl");
const util = require("util");
const __1 = require("..");
const client_1 = require("../btc/client");
const erc20_1 = require("../eth/erc20");
const geth_1 = require("../eth/geth");
const parity_1 = require("../eth/parity");
const client_2 = require("../omni/client");
const color = {
    _: "\x1b[4m",
    clear: "\x1b[0m",
    yellow: "\x1b[33m",
};
console.log(`
wallet-rpc repl by isLishude <${color._}https://github.com/islishude/wallet-rpc${color.clear}>

The available global variables are

${color.yellow}
- HttpClient(default jsonrpc client)
- BitcoinClient
- OmniClient(extends from BitcoinClient)
- GethClient
- ParityClient(extends from GethClient)
- ERC20Client(injects GethClient or ParityClient)
${color.clear}

See the README to learn more API and RPC supports list.

Run \`npx -n --experimental-repl-await wallet-rpc\` to enable top-level-await.

e.g.
${color.yellow}
  const HttpProvider = new HttpClient({ url: "http://127.0.0.1:8545" });
  const EthClient = new GethClient(HttpProvider);
  await EthClient.getChainId();
${color.clear}
`);
const terminal = repl_1.start({
    ignoreUndefined: true,
    input: process.stdin,
    output: process.stdout,
    prompt: "> ",
    terminal: process.stdout.isTTY,
    useGlobal: true,
    writer(value) {
        return util.inspect(value, {
            showHidden: false,
            depth: null,
            customInspect: true,
            colors: true,
            maxArrayLength: null,
            breakLength: 80,
            compact: false,
            sorted: false,
            // @ts-ignore
            getters: false,
        });
    },
});
terminal.context.HttpClient = __1.HttpClient;
terminal.context.BitcoinClient = client_1.BitcoinClient;
terminal.context.OmniClient = client_2.OmniClient;
terminal.context.GethClient = geth_1.GethClient;
terminal.context.ParityClient = parity_1.ParityClient;
terminal.context.ERC20Client = erc20_1.ERC20Client;
