"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const client_1 = require("../jsonrpc/client");
const reqdata_1 = require("../jsonrpc/reqdata");
class BitcoinClient {
    constructor(client) {
        this.client = client || new client_1.HttpClient({ url: "http://127.0.0.1:8332" });
    }
    getBlockchainInfo() {
        const reqData = new reqdata_1.ReqData("", "getblockchaininfo");
        return this.client.Call(reqData.getData());
    }
    getMemoryInfo() {
        const reqData = new reqdata_1.ReqData("", "getmemoryinfo");
        return this.client.Call(reqData.getData());
    }
    getMemPoolInfo() {
        const reqData = new reqdata_1.ReqData("", "getmempoolinfo");
        return this.client.Call(reqData.getData());
    }
    getBestBlockHash() {
        const reqData = new reqdata_1.ReqData("", "getbestblockhash");
        return this.client.Call(reqData.getData());
    }
    getBlockCount() {
        const reqData = new reqdata_1.ReqData("", "getblockcount");
        return this.client.Call(reqData.getData());
    }
    getBlockHash(height) {
        const reqData = new reqdata_1.ReqData("", "getblockhash", height);
        return this.client.Call(reqData.getData());
    }
    getBlock(hash) {
        const reqData = new reqdata_1.ReqData("", "getblock", hash);
        return this.client.Call(reqData.getData());
    }
    getRawTrx(txid, verbose) {
        const getVerbose = Boolean(verbose);
        const reqData = new reqdata_1.ReqData("", "getrawtransaction", txid, getVerbose);
        return this.client.Call(reqData.getData());
    }
    sendRawTx(rawTrx, highFee = false) {
        const reqData = new reqdata_1.ReqData("", "sendrawtransaction", rawTrx, highFee);
        return this.client.Call(reqData.getData());
    }
    getMemPool(verbose) {
        const reqData = new reqdata_1.ReqData("", "getrawmempool", verbose);
        return this.client.Call(reqData.getData());
    }
    estimateFee(target = 6, mode) {
        const reqData = new reqdata_1.ReqData("", "estimatesmartfee", target, mode);
        return this.client.Call(reqData.getData());
    }
    decodeRawTrx(rawTrx, isWitness = false) {
        const reqData = new reqdata_1.ReqData("", "decoderawtransaction", rawTrx, isWitness);
        return this.client.Call(reqData.getData());
    }
    getTxOut(txid, n, includeMempool = false) {
        const reqData = new reqdata_1.ReqData("", "gettxout", txid, n, includeMempool);
        return this.client.Call(reqData.getData());
    }
}
exports.BitcoinClient = BitcoinClient;
