"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const client_1 = require("../jsonrpc/client");
const reqdata_1 = require("../jsonrpc/reqdata");
class GethClient {
    constructor(client) {
        this.client = client || new client_1.HttpClient({ url: "http://127.0.0.1:8545" });
        this.NODE_VERSION = "geth";
    }
    static Hexify(status) {
        if (typeof status === "number") {
            return "0x" + status.toString(16);
        }
        return status;
    }
    getNodeVersion() {
        const reqData = new reqdata_1.ReqData("", "web3_clientVersion");
        return this.client.Call(reqData.getData());
    }
    getNetworkVersion() {
        // "1": Ethereum Mainnet
        // "2": Morden Testnet (deprecated)
        // "3": Ropsten Testnet
        // "4": Rinkeby Testnet
        // "42": Kovan Testnet
        const reqData = new reqdata_1.ReqData("", "net_version");
        return this.client.Call(reqData.getData());
    }
    getPeerCount() {
        const reqData = new reqdata_1.ReqData("", "net_peerCount");
        return this.client.Call(reqData.getData());
    }
    getChainId() {
        const reqData = new reqdata_1.ReqData("", "eth_chainId");
        return this.client.Call(reqData.getData());
    }
    getProtocalVersion() {
        const reqData = new reqdata_1.ReqData("", "eth_protocolVersion");
        return this.client.Call(reqData.getData());
    }
    getBalance(address, status = "latest") {
        const block = GethClient.Hexify(status);
        const reqData = new reqdata_1.ReqData("", "eth_getBalance", address, block);
        return this.client.Call(reqData.getData());
    }
    getTrxCount(address, status = "latest") {
        const method = "eth_getTransactionCount";
        const block = GethClient.Hexify(status);
        const reqData = new reqdata_1.ReqData("", method, address, block);
        return this.client.Call(reqData.getData());
    }
    getBlockNumber() {
        const reqData = new reqdata_1.ReqData("", "eth_blockNumber");
        return this.client.Call(reqData.getData());
    }
    getBlock(height, verbose) {
        const num = "0x" + height.toString(16);
        const reqData = new reqdata_1.ReqData("", "eth_getBlockByNumber", num, !!verbose);
        return this.client.Call(reqData.getData());
    }
    getTrx(hash) {
        const reqData = new reqdata_1.ReqData("", "eth_getTransactionByHash", hash);
        return this.client.Call(reqData.getData());
    }
    getTrxReceipt(hash) {
        const reqData = new reqdata_1.ReqData("", "eth_getTransactionReceipt", hash);
        return this.client.Call(reqData.getData());
    }
    getCode(address, status = "latest") {
        const block = GethClient.Hexify(status);
        const reqData = new reqdata_1.ReqData("", "eth_getCode", address, block);
        return this.client.Call(reqData.getData());
    }
    sendRawTrx(data) {
        const reqData = new reqdata_1.ReqData("", "eth_sendRawTransaction", data);
        return this.client.Call(reqData.getData());
    }
    callContract(data, status = "latest", state) {
        const block = GethClient.Hexify(status);
        const reqData = new reqdata_1.ReqData("", "eth_call", data, block, state);
        return this.client.Call(reqData.getData());
    }
    estimateGas(data, status = "latest") {
        const block = GethClient.Hexify(status);
        const reqData = new reqdata_1.ReqData("", "eth_estimateGas", data, block);
        return this.client.Call(reqData.getData());
    }
    syncingStatus() {
        const reqData = new reqdata_1.ReqData("", "eth_syncing");
        return this.client.Call(reqData.getData());
    }
    gasPrice() {
        const reqData = new reqdata_1.ReqData("", "eth_gasPrice");
        return this.client.Call(reqData.getData());
    }
    txpoolContent() {
        const reqData = new reqdata_1.ReqData("", "txpool_content");
        return this.client.Call(reqData.getData());
    }
    txpoolInspect() {
        const reqData = new reqdata_1.ReqData("", "txpool_inspect");
        return this.client.Call(reqData.getData());
    }
    txpoolStatus() {
        const reqData = new reqdata_1.ReqData("", "txpool_status");
        return this.client.Call(reqData.getData());
    }
    fillTrx(rawTrx) {
        const reqData = new reqdata_1.ReqData("", "eth_fillTransaction", rawTrx);
        return this.client.Call(reqData.getData());
    }
}
exports.GethClient = GethClient;
