"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const http = require("http");
const https = require("https");
const urllib = require("url");
class HttpClient {
    constructor(config) {
        const { url, username, password, keepAlive, timeout } = config;
        this.httpModule = /^https:.+$/g.test(url) ? https : http;
        this.httpAgent = new this.httpModule.Agent({
            keepAlive: keepAlive || false,
        });
        this.options = {
            agent: this.httpAgent,
            auth: config.username || config.password
                ? `${username || ""}@${password || ""}`
                : undefined,
            headers: {
                "Accept": "application/json",
                "Accept-Encoding": "identity",
                "User-Agent": "islishude/walletrpc",
                "Content-Type": "application/json",
            },
            method: "POST",
            timeout: timeout || 60000,
        };
        this.setUrl(url);
    }
    setAuth(username, password) {
        if (username === "" && password === "") {
            return;
        }
        this.options.auth = `${username}@${password}`;
    }
    setUrl(url) {
        const { host, hostname, port } = urllib.parse(url);
        this.options.host = host;
        this.options.hostname = hostname;
        if (port) {
            this.options.port = Number.parseInt(port, 10);
        }
        this.httpModule = /^https:.+$/g.test(url) ? https : http;
        this.url = url;
    }
    Call(data) {
        return new Promise((resolve, reject) => {
            const client = this.httpModule.request(this.options, (res) => {
                res.on("error", reject);
                const chunk = [];
                res.on("data", (tmp) => {
                    chunk.push(tmp);
                });
                res.on("end", () => {
                    const returns = {
                        body: JSON.parse(Buffer.concat(chunk).toString()),
                        headers: res.headers,
                        statusCode: res.statusCode,
                    };
                    resolve(returns);
                });
            });
            client.setHeader("Content-Length", Buffer.byteLength(data));
            client.write(data);
            client.on("error", reject);
            client.on("timeout", () => reject(new Error("timeout")));
        });
    }
    Close() {
        this.httpAgent.destroy();
    }
}
exports.HttpClient = HttpClient;
